@@ -78,3 +78,5 @@ admin.site.register(WorkOrderService)
 admin.site.register(WorkOrderStatus)
 admin.site.register(Config)
 admin.site.register(PowerVend)
+admin.site.register(Bedroom)
+admin.site.register(WorkOrderBedroom)
